@@ -32,6 +32,8 @@ GIT_BEGIN_DECL
  *
  * @param delta The delta to be applied
  * @param payload User-specified payload
+ * @return 0 if the delta is applied, < 0 if the apply process will be aborted
+ *	or > 0 if the delta will not be applied.
  */
 typedef int GIT_CALLBACK(git_apply_delta_cb)(
 	const git_diff_delta *delta,
@@ -48,30 +50,61 @@ typedef int GIT_CALLBACK(git_apply_delta_cb)(
  *
  * @param hunk The hunk to be applied
  * @param payload User-specified payload
+ * @return 0 if the hunk is applied, < 0 if the apply process will be aborted
+ *	or > 0 if the hunk will not be applied.
  */
 typedef int GIT_CALLBACK(git_apply_hunk_cb)(
 	const git_diff_hunk *hunk,
 	void *payload);
 
+/** Flags controlling the behavior of git_apply */
+typedef enum {
+	/**
+	 * Don't actually make changes, just test that the patch applies.
+	 * This is the equivalent of `git apply --check`.
+	 */
+	GIT_APPLY_CHECK = (1 << 0)
+} git_apply_flags_t;
+
 /**
  * Apply options structure
  *
  * Initialize with `GIT_APPLY_OPTIONS_INIT`. Alternatively, you can
- * use `git_apply_init_options`.
+ * use `git_apply_options_init`.
  *
  * @see git_apply_to_tree, git_apply
  */
 typedef struct {
-	unsigned int version;
+	unsigned int version; /**< The version */
 
+	/** When applying a patch, callback that will be made per delta (file). */
 	git_apply_delta_cb delta_cb;
+
+	/** When applying a patch, callback that will be made per hunk. */
 	git_apply_hunk_cb hunk_cb;
+
+	/** Payload passed to both delta_cb & hunk_cb. */
 	void *payload;
+
+	/** Bitmask of git_apply_flags_t */
+	unsigned int flags;
 } git_apply_options;
 
 #define GIT_APPLY_OPTIONS_VERSION 1
 #define GIT_APPLY_OPTIONS_INIT {GIT_APPLY_OPTIONS_VERSION}
 
+/**
+ * Initialize git_apply_options structure
+ *
+ * Initialize a `git_apply_options` with default values. Equivalent to creating
+ * an instance with GIT_APPLY_OPTIONS_INIT.
+ *
+ * @param opts The `git_apply_options` struct to initialize.
+ * @param version The struct version; pass `GIT_APPLY_OPTIONS_VERSION`
+ * @return 0 on success or -1 on failure.
+ */
+GIT_EXTERN(int) git_apply_options_init(git_apply_options *opts, unsigned int version);
+
 /**
  * Apply a `git_diff` to a `git_tree`, and return the resulting image
  * as an index.
@@ -81,6 +114,7 @@ typedef struct {
  * @param preimage the tree to apply the diff to
  * @param diff the diff to apply
  * @param options the options for the apply (or null for defaults)
+ * @return 0 or an error code
  */
 GIT_EXTERN(int) git_apply_to_tree(
 	git_index **out,
@@ -89,6 +123,7 @@ GIT_EXTERN(int) git_apply_to_tree(
 	git_diff *diff,
 	const git_apply_options *options);
 
+/** Possible application locations for git_apply */
 typedef enum {
 	/**
 	 * Apply the patch to the workdir, leaving the index untouched.
@@ -106,7 +141,7 @@ typedef enum {
 	 * Apply the patch to both the working directory and the index.
 	 * This is the equivalent of `git apply --index`.
 	 */
-	GIT_APPLY_LOCATION_BOTH = 2,
+	GIT_APPLY_LOCATION_BOTH = 2
 } git_apply_location_t;
 
 /**
@@ -117,6 +152,7 @@ typedef enum {
  * @param diff the diff to apply
  * @param location the location to apply (workdir, index or both)
  * @param options the options for the apply (or null for defaults)
+ * @return 0 or an error code
  */
 GIT_EXTERN(int) git_apply(
 	git_repository *repo,
